#
# spec file for package wlroots
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  libcap
%bcond_without  systemd
%bcond_with     elogind
%bcond_without  x11_backend
%bcond_without  xwayland
%bcond_without  xcb_errors
Name:           wlroots
Version:        0.10.1
Release:        bp153.1.24
Summary:        Modular Wayland compositor library
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/swaywm/wlroots
Source0:        https://github.com/swaywm/wlroots/archive/%{version}.tar.gz
BuildRequires:  meson >= 0.48.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(freerdp2)
BuildRequires:  pkgconfig(gbm) >= 17.1.0
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libdrm) >= 2.4.95
BuildRequires:  pkgconfig(libinput) >= 1.9.0
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.16
BuildRequires:  pkgconfig(wayland-server) >= 1.16
BuildRequires:  pkgconfig(xkbcommon)
%if %{with libcap}
BuildRequires:  pkgconfig(libcap)
%endif
%if %{with systemd}
BuildRequires:  pkgconfig(libsystemd)
%endif
%if %{with elogind}
BuildRequires:  pkgconfig(libelogind)
%endif
%if %{with x11_backend} || %{with xwayland}
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xkb)
%if %{with xcb_errors}
BuildRequires:  pkgconfig(xcb-errors)
%endif
%endif

%description
Pluggable, composable modules for building a Wayland compositor.

%package devel
Summary:        Modular Wayland compositor library
Group:          Development/Libraries/C and C++
Requires:       libwlroots5 = %{version}

%description devel
Pluggable, composable modules for building a Wayland compositor.

%package -n libwlroots5
Summary:        Modular Wayland compositor library
Group:          System/Libraries

%description -n libwlroots5
Pluggable, composable modules for building a Wayland compositor.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -I/usr/include/wayland -Wno-redundant-decls"
%meson \
  %{?with_libcap:-Denable-libcap=true} \
%if 0%{?suse_version} >= 1550
  %{?with_systemd:-Denable-systemd=true} \
  %{?with_elogind:-Denable-elogind=true} \
%else
  -Dlogind=disabled \
%endif
  %{?with_x11_backend:-Denable-x11_backend=true} \
  %{?with_xwayland:-Denable-xwayland=true} \
  %{?with_xcb_errors:-Denable-xcb_errors=true}
%meson_build

%install
%meson_install

%post   -n libwlroots5 -p /sbin/ldconfig
%postun -n libwlroots5 -p /sbin/ldconfig

%files devel
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_includedir}/wlr/
%{_libdir}/pkgconfig/wlroots.pc
%{_libdir}/libwlroots.so

%files -n libwlroots5
%{_libdir}/libwlroots.so.*

%changelog
* Thu Mar 12 2020 Max Lin <mlin@suse.com>
- Disable logind support in Leap 15, we don't have systemd >= 237,
  neither elogind.
* Wed Mar 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.10.1:
  * xdg-shell: fix popups rendered outside of the screen
  * meson: Fix protocol includes for compositor examples
  * examples: Fix compositor-examples
  * xwayland: ignore pointer focus changes
* Thu Jan 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * The RDP backend has been removed entirely in favor of solutions
    like wayvnc
  * Code cleanups and bug fixes
* Mon Jan 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  * virtual-pointer: Actually use the value passed to axis_discrete
  * xwm: allow applications to change focus between their own surfaces
  * backend/wayland: fix frame callback not registered
* Fri Jan  3 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  * layer_shell: set layer of existing surface #1842
  * backend/drm: add support for custom modes #1881
  * Simplify globals implementation by removing destructors #1915
  * Improve presentation-time API #1919
  * output: re-introduce atomic mode, enabled, scale and transform #1797
  * See for details: https://github.com/swaywm/wlroots/releases/tag/0.9.0
- Changes form 0.8.0:
  * presentation_feedback: add the sampled state
  * See for details: https://github.com/swaywm/wlroots/releases/tag/0.8.0
* Tue Aug 27 2019 mvetter@suse.com
- Update to 0.7.0:
  * backend: touch: Assign good ids to single touch devices
  * backend: touch: Fixup incomplete patch for single touch devices.
  * render/drm: keep old drm_format if realloc fails
  * xcursor: avoid leak and loss of all cursors if cursors realloc fails
  * Fix memory leak
  * Simplify check
  * wlr_surface: condition is always false
  * xdg_shell: remove variable self-assignment
  * backend/session: non-void function should return a value
  * backend/drm: use UINT64_C for uint64_t literals
  * Avoid loss of a fractional part
  * backend/wayland: check if zxdg_toplevel_decoration_v1 is not NULL
  * xwayland: prevent possible array overrun
  * examples: remove duplicated condition
  * Use a set to track pointer button state.
  * session/logind: keep active for pause_device gone
  * zwp_virtual-keyboard: fix mmap error handling
  * wlr_xdg_toplevel: reparent on parent unmap
  * wlr-layer-shell-v1: destroy xdg popups on unmap
  * x11: Send a frame event on the pointer after button events
  * virtual_keyboard: Require keymap before accepting keycodes
  * Remove rootston
  * Add libinput-1.14 support
  * Revert "render/drm: keep old drm_format if realloc fails"
  * Add _incr_version to contrib/
  * Support pointer-gestures on Wayland backend
  * wlr_seat_touch: Don't destroy touch point with surface
  * layer-shell: Remove unused event source
  * layer-shell: Reject requests on gone surfaces
  * text_input: Don't forget to send enter events
  * output: clear output->damage on successful commit
  * output-damage: set needs swap only when we have new damage
  * session/logind: specify seat exactly
  * session/logind: check for XDG_SESSION_ID first
  * screencopy: fix segfault on disabled output
  * screencopy: send failed after output disconnect
  * export-dmabuf-v1: fix segfault on output disable
  * Implement serial validation for selection requests
  * wlr_seat: Fix edge cases with serial validation
  * wlr_pointer_gestures: Register event serials
  * wlr_tablet_v2: Register event serials
  * wlr_seat: special-case first serial set use
  * Use -fmacro-prefix-map to strip build path
  * Fixes #1689 RDP RemoteFX crash
  * wlr_output: remove idle_done on output destroy
  * drm: legacy: issue a NULL modeset on disable
  * backend: drm: switch to pageflip_handler_2
  * backend/drm: destroy output immediately
  * Revert "output: atomic mode"
  * seat: Move focus back to first shell surface when unfocusing layer surface
  * xdg_shell(_v6): Take maximize/fullscreen state into account on view init
  * wlr_touch: Declare wlr_touch_impl usage as const
  * backends/x11: Touch support
  * wlr_input_method_v2: Remove input method's resource from the list on destroy
  * wlr_seat_touch: add a way for a grab to ignore a touch point
  * wlr_xdg_popup: grab touch events alongside pointer and keyboard
  * wlr_xdg_popup: don't treat all surfaces of grabbing client as grabbing surfaces
  * backend/wayland: use xdg-decoration-unstable-v1
  * backend/wayland: remove wl_shm
  * render/gles2: print GL_RENDERER
  * Remove orbital screenshooter and gamma-control
  * backend/drm: check format when scanning out DMA-BUF
  * backend/drm: strip alpha channel on scan-out
  * render/dmabuf: add wlr_dmabuf_attributes_copy
  * buffer: add wlr_buffer_get_dmabuf
  * output: change set_dmabuf to attach_buffer
  * output: fix attach_buffer semantics
  * output: save buffer in pending state
  * backend/drm: hold buffers while scanning out
  * backend/drm: reject DMA-BUFs with flags
  * rootston: add support for direct scan-out
  * output: refuse to scan-out if software cursors are used
  * output: introduce wlr_output_lock_attach_render
  * output-damage: support direct scan-out
  * backend/drm: fallback to drmModeAddFB2
  * backend/drm: add support for multiplanar BOs
  * output: reset the pending state on failed commit
  * output: remove wlr_output_impl.transform
  * output: drop wlr_output_mode.flags
  * Remove all wayland-server.h includes
  * output: atomic mode, enabled, scale and transform
  * xdg-output: add support for xdg-output-unstable-v1 version 3
  * backend/drm: fix missing plane formats
* Mon May  6 2019 mvetter@suse.com
- Update to 0.6.0:
  * We have removed the long-deprecated wl_shell implementation from wlroots.
  * output: refactor frame submission API
  * output: remove lx, ly
  * Rename lid_switch to switch_device to disambiguate lid and tablet mode switches
  * Add FreeRDP backend for remote desktop support
- Remove wlroots-0.3-libinput-include.patch: not needed anymore
* Tue Mar 12 2019 mvetter@suse.com
- Update to 0.5.0:
  * DISPLAY is no longer set automatically for Xwayland
  * wlr_output_layout_get_box: handle empty layout
  * Unbreak build with '-Wstrict-prototypes'
  * rootston/view: Remove redundant declaration in the same file
  * wlr_xdg_shell: Remove redundant declaration in the same file
  * Remove glEGLImageTargetTexture2DOES
  * seat: fix remaining wlr_button_state enum rename
  * xwm: use min size as base size hint if it is missing and vice versa
  * xwm: fix typos in WM_NORMAL_HINTS handling
  * backend/session: Allow setting a custom tty via WLR_DIRECT_TTY
  * backend/drm: Don't fail on failing to find overlay format
  * seat: guard against button count corruption
  * meson: enable more compiler warnings
  * seat: use wlr_button_state enum instead of uint32_t
  * seat: only store serial if pressing a button
  * tinywl: send pointer frame events
  * backend/session: add noop session
  * rootston: refactor rendering
  * rootston: fix rotated views rendering
  * rootston: fix Xwayland children rendering when fullscreen
  * rootston: split rendering code into render.c
  * rootston: fix input events for rotated views
  * xwayland: don't set DISPLAY
  * seat: add debug logs when validating grab serials
  * backend/session: open TTY with O_CLOEXEC for direct session
  * xwayland: set CLOEXEC on /dev/null FD
- Compile with -Wno-redundant-decls
  See: https://gitlab.freedesktop.org/wayland/wayland/issues/82
* Thu Feb 28 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1:
  * rootston: Make add_{switch,binding}_config static
  * clang compile fix#1572[1]
* Tue Feb 26 2019 mvetter@suse.com
- Update to 0.4:
  * xwm: stack below on map
  * drm: do not modeset to current mode
  * wlr_output: do not modeset to current mode
  * backend/drm: fix modeset on drm fd resume
  * Make popup inert when destroyed.
  * Add build-*/ to gitignore.
  * Revert "drm: do not modeset to current mode"
  * Add a wlr_output_set_subpixel()
  * data-control: add primary selection support
  * Prevent NULL dereference in tablet_tool handler
  * backend/drm: fix memory leak in realloc crtcs
  * backend/drm: Unset cursor on cleanup
  * Post protocol error on invalid wl_surface scale
  * rootston: don't try to maximize fullscreen surfaces
  * rootston: surface_at: check for fullscreen surfaces in between TOP and OVERLAY layers
  * xwm: Add _NET_CLIENT_LIST support
  * Allow cursor render surface to be used as fb
  * Copy cursor surface to secondary gpu if necessary
  * Add workaround for hardware cursors on nouveau
  * data-device: destroy previous source when starting drag
  * xdg-shell: destroy child popups on unmap
  * Deprecate old protocols
  * primary-selection-v1: copy from gtk-primary-selection
  * surface: error out on invalid transform
  * subsurface: add map/unmap events
  * xwayland, data-device: fix surface state on unmap
  * data-device: make old offers inert before sending selection
  * backend/drm: fix NULL dereference when unsetting cursor
  * xwayland: don't use SOCK_CLOEXEC
  * xwayland: remove remaining SOCK_CLOEXEC
  * data-device: refactor wlr_drag
  * data-device: fix drag cleanup if not started
  * rootston: cancel drag on invalid serial
  * data-offer: send WL_DATA_OFFER_ERROR_INVALID_FINISH
  * data-device: unbreak wl_data_source.cancel during drag-and-drop
  * rootston: move part of desktop.c to view.c, use an interface for views
  * rootston: add a view child interface
  * rootston: make roots_view embedded and remove unions
  * data-device: check if there's a source before sending dnd_finish
  * Allow compositors to run as systemd user units
* Mon Feb  4 2019 mvetter@suse.com
- Update to 0.3:
  * gtk-primary-selection: refactor everything, untie from seat (#1397).
    Various properties related to this unstable protocol have been
    removed from wlr_seat and wlr_seat_client. Use wlr_gtk_primary_selection_* instead.
  * output: switch wlr_output_swap_buffers damage to output-buffer-local coords (#1403)
  * Standardize the wlr_box input paramaters (#1441). The destination
    parameter is now always the first one.
  * Remove wlr_xdg_surface_send_close (#1461). Use
    wlr_xdg_toplevel_send_close and wlr_xdg_popup_destroy instead.
  * data-device, primary-selection: add request_set_selection (#1402).
    Compositors now need to listen on wlr_seat.events.request_set_selection
    and wlr_seat.events.request_set_primary_selection, then decide whether or not to
    accept the request with wlr_seat_set_selection and wlr_seat_set_primary_selection.
  * wlr_seat_client_send_selection has been removed, this is an internal function (#1427)
  * wlr_data_source_finish has been removed, this is now handled
    by wlr_data_source_destroy (#1427)
  * wlr_data_source_cancel has been renamed to wlr_data_source_destroy (#1427)
  * Compositors now need to listen on the wlr_pointer.frame or wlr_cursor.frame
    events, and call wlr_seat_notify_frame (#1503). If you're simulating pointer events,
    you'll need to call wlr_seat_notify_frame manually.
- Add wlroots-0.3-libinput-include.patch: fix include
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid pointless scriptlet dependency on /bin/sh.
- Avoid double-shipping documentation.
* Fri Jan 25 2019 mvetter@suse.com
- Update description
* Thu Jan 24 2019 mvetter@suse.com
- Adjust spec file to not use git but version 0.2
* Thu May 17 2018 rzl@l2f.inesc-id.pt
- Initial version
